==> jreen_1.1.1.orig.tar.bz2: libjreen-1.1.1/src/bookmarkfactory_p.h <==
/****************************************************************************
**
** Jreen
**
** Copyright © 2011 Aleksey Sidorov <gorthauer87@yandex.ru>
**
*****************************************************************************
**
** $JREEN_BEGIN_LICENSE$
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see http://www.gnu.org/licenses/.
** $JREEN_END_LICENSE$
**
****************************************************************************/

#ifndef BOOKMARKFACTORY_H
#define BOOKMARKFACTORY_H
#include "bookmark.h"

namespace Jreen {

class JREEN_AUTOTEST_EXPORT BookmarkFactory : public PayloadFactory<Bookmark>
{
public:
	BookmarkFactory();
	virtual ~BookmarkFactory();
	QStringList features() const;
	bool canParse(const QStringRef &name, const QStringRef &uri, const QXmlStreamAttributes &attributes);
	void handleStartElement(const QStringRef &name, const QStringRef &uri, const QXmlStreamAttributes &attributes);
	void handleEndElement(const QStringRef &name, const QStringRef &uri);
	void handleCharacterData(const QStringRef &text);
	void serialize(Payload *extension, QXmlStreamWriter *writer);
	Payload::Ptr createPayload();
private:
	enum State { AtNick, AtPassword, AtNowhere, AtConference };
	State m_state;
	int m_depth;
	QScopedPointer<Bookmark> m_bookmark;
	Bookmark::Conference m_conference;
};

} // namespace Jreen

#endif // BOOKMARKFACTORY_H

==> jreen_1.2.0.orig.tar.bz2: libjreen-1.2.0/src/bookmarkfactory_p.h <==
/****************************************************************************
**
** Jreen
**
** Copyright © 2011 Aleksey Sidorov <gorthauer87@yandex.ru>
**
*****************************************************************************
**
** $JREEN_BEGIN_LICENSE$
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see http://www.gnu.org/licenses/.
** $JREEN_END_LICENSE$
**
****************************************************************************/

#ifndef JREEN_BOOKMARKFACTORY_P_H
#define JREEN_BOOKMARKFACTORY_P_H
#include "bookmark.h"

namespace Jreen {

class JREEN_AUTOTEST_EXPORT BookmarkFactory : public PayloadFactory<Bookmark>
{
public:
	BookmarkFactory();
	virtual ~BookmarkFactory();
	QStringList features() const;
	bool canParse(const QStringRef &name, const QStringRef &uri, const QXmlStreamAttributes &attributes);
	void handleStartElement(const QStringRef &name, const QStringRef &uri, const QXmlStreamAttributes &attributes);
	void handleEndElement(const QStringRef &name, const QStringRef &uri);
	void handleCharacterData(const QStringRef &text);
	void serialize(Payload *extension, QXmlStreamWriter *writer);
	Payload::Ptr createPayload();
private:
	enum State { AtNick, AtPassword, AtNowhere, AtConference };
	State m_state;
	int m_depth;
	QScopedPointer<Bookmark> m_bookmark;
	Bookmark::Conference m_conference;
};

} // namespace Jreen

#endif // JREEN_BOOKMARKFACTORY_P_H
